package de.upb.infexba.ml;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * IO class for writing feature names and values to an ARFF
 * file and reading the names of a feature set previously written
 * to such a file.
 * 
 * @author hwachsmuth, 2010/11/25
 *
 */
public class GeneralFeatureARFFReader {
	
	/**
	 * Reads the names of the feature set in the specified location and
	 * returns them as a list.
	 * 
	 * @param location The location
	 * @return The list of names
	 */
	public List<String> readFeatureSetFromARFF(String location){
		try{
			List<String> featureNames = new ArrayList<String>();
			BufferedReader in = new BufferedReader(new FileReader(location));
			String line = in.readLine();
			while (line != null){
				if (line.startsWith("@ATTRIBUTE")){
					int beginIndex = 11;
					int endIndex = 12;
					while (!Character.isWhitespace(line.charAt(endIndex)))
						endIndex++;
					String name = line.substring(beginIndex, endIndex);
					if (!name.equals("class")) featureNames.add(name);
					else break;
				}
				line = in.readLine();
			}
			return featureNames;
		}
		catch (IOException ioe){
			ioe.printStackTrace();
			return null;
		}
	}
}