package de.upb.infexba.ml.feature.ngram;

import java.util.HashMap;

import org.apache.uima.cas.FSIterator;
import org.apache.uima.jcas.JCas;
import org.apache.uima.jcas.tcas.Annotation;

import de.upb.infexba.Token;
import de.upb.infexba.ml.feature.FeatureHandler;
import de.upb.infexba.ml.feature.GenreFeatureHandler;
import de.upb.infexba.ml.feature.partofspeech.PartOfSpeechConstants;

public class POSNgramHandler extends NgramHandler {

	static String FEATURE_PREFIX = "posNgram_";

	public POSNgramHandler(int n) {
		super(n);
	}

	public boolean canHandle(String feature) {
		return feature.startsWith(POSNgramHandler.FEATURE_PREFIX);
	}

	String getFeatureName(Object[] ngram) {
		String str = "";
		for (int i = 0; i < ngram.length; i++) {
			Object pos = ngram[i];
			if (pos instanceof String) {
				str += PartOfSpeechConstants.getPosAsText((String) pos);
				if (i < ngram.length - 1)
					str += "_";
			} else
				System.out.println("Error in computeCode of POSNgram: An entry of this.objects is no String.");
		}
		return POSNgramHandler.FEATURE_PREFIX + str;
	}

	public static String getTextFromFeatureName(String feature) {
		return feature.substring(POSNgramHandler.FEATURE_PREFIX.length() + 1);
	}

	public void handleInMap(JCas jcas, HashMap<String, Double> map) {

		FSIterator<Annotation> tokenIterator = jcas.getAnnotationIndex(Token.type).iterator();
		Token token;
		String[] window = new String[this.n];

		// fill first window
		for (int i = 0; i < this.n && tokenIterator.hasNext(); i++) {
			token = (Token) tokenIterator.next();
			window[i] = token.getPos().toUpperCase();
		}
		this.increaseInMap(map, getFeatureName(window), 1.);

		while (tokenIterator.hasNext()) {
			token = (Token) tokenIterator.next();
			// shift left by one
			System.arraycopy(window, 1, window, 0, window.length - 1);
			// next pos
			window[window.length - 1] = token.getPos().toUpperCase();

			this.increaseInMap(map, getFeatureName(window), 1.);
		}
	}

	public double getNormalizedValue(String feature, double value, Double numberOfTokens) {
		if (this.normalizationMode == NO_FACTORS)
			return 1. * value / numberOfTokens;

		double factor = 1.;
		if (this.normalizationMode == FeatureHandler.MY_NORMALIZATION) {
			factor = 10.;
			if (GenreFeatureHandler.isGenreSpecificFeature(feature)) {
				factor = 100.;
			}

		}
		
		else if(this.normalizationMode == FeatureHandler.CALCULATED_MAXIMA_MUSIC){
			 if(feature.equals("posNgram_ADJA_XY_ADJA|gs"))
					factor = 26.249999999999996;
				else if(feature.equals("posNgram_ADJA_XY_NN|gs"))
					factor = 62.5;
				else if(feature.equals("posNgram_ADJD_APPR_PDAT|gs"))
					factor = 83.0;
				else if(feature.equals("posNgram_ADJD_NE_SATZINTERN|gs"))
					factor = 72.5;
				else if(feature.equals("posNgram_ADV_SATZENDE_PPER|gs"))
					factor = 104.0;
				else if(feature.equals("posNgram_ADV_SATZENDE_SATZENDE|gs"))
					factor = 38.666666666666664;
				else if(feature.equals("posNgram_CARD_NN_FM|gs"))
					factor = 75.0;
				else if(feature.equals("posNgram_CARD_PDAT_NN|gs"))
					factor = 62.5;
				else if(feature.equals("posNgram_CARD_PPER_VAFIN|gs"))
					factor = 82.0;
				else if(feature.equals("posNgram_CARD_SATZENDE_CARD|gs"))
					factor = 87.0;
				else if(feature.equals("posNgram_CARD_SATZINTERN_CARD|gs"))
					factor = 14.705882352941176;
				else if(feature.equals("posNgram_FM_XY_ADJA|gs"))
					factor = 44.333333333333336;
				else if(feature.equals("posNgram_FM_XY_FM|gs"))
					factor = 19.5;
				else if(feature.equals("posNgram_FM_XY_NE|gs"))
					factor = 98.00000000000001;
				else if(feature.equals("posNgram_KOMMA_VMFIN_PPER|gs"))
					factor = 113.0;
				else if(feature.equals("posNgram_KON_KON_KON|gs"))
					factor = 3.8780487804878048;
				else if(feature.equals("posNgram_NE_FM_ADJA|gs"))
					factor = 139.0;
				else if(feature.equals("posNgram_NE_XY_ADJA|gs"))
					factor = 66.0;
				else if(feature.equals("posNgram_NN_CARD_PDAT|gs"))
					factor = 95.0;
				else if(feature.equals("posNgram_NN_CARD_PPER|gs"))
					factor = 29.0;
				else if(feature.equals("posNgram_SATZENDE_NN_PRF|gs"))
					factor = 53.0;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_ADJA|gs"))
					factor = 106.0;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_ADJD|gs"))
					factor = 50.0;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_ADV|gs"))
					factor = 58.0;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_PPER|gs"))
					factor = 47.5;
				else if(feature.equals("posNgram_SATZINTERN_ADJA_XY|gs"))
					factor = 81.0;
				else if(feature.equals("posNgram_SATZINTERN_CARD_ADJA|gs"))
					factor = 22.90909090909091;
				else if(feature.equals("posNgram_SATZINTERN_KON_PPER|gs"))
					factor = 82.0;
				else if(feature.equals("posNgram_SATZINTERN_NN_XY|gs"))
					factor = 84.0;
				else if(feature.equals("posNgram_VAFIN_ADV_CARD|gs"))
					factor = 106.0;
				else if(feature.equals("posNgram_VAFIN_NN_PRF|gs"))
					factor = 86.0;
				else if(feature.equals("posNgram_VAFIN_SATZENDE_SATZENDE|gs"))
					factor = 47.5;
				else if(feature.equals("posNgram_VVINF_SATZENDE_SATZENDE|gs"))
					factor = 78.0;
				else if(feature.equals("posNgram_VVPP_KOMMA_KOUI|gs"))
					factor = 91.0;
				else if(feature.equals("posNgram_XY_ADJA_XY|gs"))
					factor = 21.0;
				else if(feature.equals("posNgram_XY_APPR_XY|gs"))
					factor = 110.0;
				else if(feature.equals("posNgram_XY_FM_XY|gs"))
					factor = 19.5;
				else if(feature.equals("posNgram_XY_NE_NE|gs"))
					factor = 114.0;
				else if(feature.equals("posNgram_XY_NE_SATZINTERN|gs"))
					factor = 55.5;
				else if(feature.equals("posNgram_XY_NN_SATZINTERN|gs"))
					factor = 42.5;
				else if(feature.equals("posNgram_XY_NN_XY|gs"))
					factor = 46.0;
				else if(feature.equals("posNgram_XY_VVFIN_ART|gs"))
					factor = 98.00000000000001;
				else if(feature.equals("posNgram_XY_XY_SATZINTERN|gs"))
					factor = 16.7;
				else if(feature.equals("posNgram_XY_XY_XY|gs"))
					factor = 5.777777777777778;
				else if(feature.equals("posNgram_ADJA_ADJA_NN|top"))
					factor = 29.0;
				else if(feature.equals("posNgram_ADJA_NN_ADJA|top"))
					factor = 28.666666666666668;
				else if(feature.equals("posNgram_ADJA_NN_ADJD|top"))
					factor = 51.50000000000001;
				else if(feature.equals("posNgram_ADJA_NN_ADV|top"))
					factor = 44.0;
				else if(feature.equals("posNgram_ADJA_NN_APPR|top"))
					factor = 27.400000000000002;
				else if(feature.equals("posNgram_ADJA_NN_ART|top"))
					factor = 29.0;
				else if(feature.equals("posNgram_ADJA_NN_KOMMA|top"))
					factor = 23.75;
				else if(feature.equals("posNgram_ADJA_NN_KON|top"))
					factor = 43.666666666666664;
				else if(feature.equals("posNgram_ADJA_NN_NE|top"))
					factor = 43.0;
				else if(feature.equals("posNgram_ADJA_NN_NN|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_ADJA_NN_SATZENDE|top"))
					factor = 27.0;
				else if(feature.equals("posNgram_ADJA_NN_SATZINTERN|top"))
					factor = 14.5;
				else if(feature.equals("posNgram_ADJA_NN_VAFIN|top"))
					factor = 45.0;
				else if(feature.equals("posNgram_ADJA_NN_VVFIN|top"))
					factor = 37.333333333333336;
				else if(feature.equals("posNgram_ADJA_SATZINTERN_NN|top"))
					factor = 22.0;
				else if(feature.equals("posNgram_ADJD_ADJA_NN|top"))
					factor = 40.5;
				else if(feature.equals("posNgram_ADV_ADJA_NN|top"))
					factor = 29.0;
				else if(feature.equals("posNgram_ADV_ADV_ADJD|top"))
					factor = 42.666666666666664;
				else if(feature.equals("posNgram_ADV_ADV_ADV|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_ADV_ADV_APPR|top"))
					factor = 36.75;
				else if(feature.equals("posNgram_ADV_APPR_ART|top"))
					factor = 39.0;
				else if(feature.equals("posNgram_ADV_ART_ADJA|top"))
					factor = 31.0;
				else if(feature.equals("posNgram_ADV_ART_NN|top"))
					factor = 20.0;
				else if(feature.equals("posNgram_APPRART_ADJA_NN|top"))
					factor = 31.666666666666664;
				else if(feature.equals("posNgram_APPR_ADJA_NN|top"))
					factor = 26.333333333333332;
				else if(feature.equals("posNgram_APPR_ART_ADJA|top"))
					factor = 31.0;
				else if(feature.equals("posNgram_APPR_ART_NN|top"))
					factor = 17.8;
				else if(feature.equals("posNgram_APPR_NE_NE|top"))
					factor = 38.5;
				else if(feature.equals("posNgram_APPR_PDAT_NN|top"))
					factor = 58.0;
				else if(feature.equals("posNgram_APPR_PPOSAT_NN|top"))
					factor = 47.0;
				else if(feature.equals("posNgram_ART_ADJA_NN|top"))
					factor = 11.6;
				else if(feature.equals("posNgram_ART_NN_ADV|top"))
					factor = 40.0;
				else if(feature.equals("posNgram_ART_NN_APPR|top"))
					factor = 25.666666666666668;
				else if(feature.equals("posNgram_ART_NN_ART|top"))
					factor = 33.0;
				else if(feature.equals("posNgram_ART_NN_KOMMA|top"))
					factor = 31.5;
				else if(feature.equals("posNgram_ART_NN_KON|top"))
					factor = 35.800000000000004;
				else if(feature.equals("posNgram_ART_NN_NN|top"))
					factor = 28.599999999999998;
				else if(feature.equals("posNgram_ART_NN_SATZENDE|top"))
					factor = 37.25;
				else if(feature.equals("posNgram_ART_NN_SATZINTERN|top"))
					factor = 23.0;
				else if(feature.equals("posNgram_ART_NN_VAFIN|top"))
					factor = 38.5;
				else if(feature.equals("posNgram_ART_NN_VVFIN|top"))
					factor = 31.0;
				else if(feature.equals("posNgram_FM_NN_NN|top"))
					factor = 54.0;
				else if(feature.equals("posNgram_KOMMA_ADJA_NN|top"))
					factor = 32.666666666666664;
				else if(feature.equals("posNgram_KOMMA_ART_NN|top"))
					factor = 42.333333333333336;
				else if(feature.equals("posNgram_KOMMA_KOUS_PPER|top"))
					factor = 43.5;
				else if(feature.equals("posNgram_KOMMA_NE_NE|top"))
					factor = 32.666666666666664;
				else if(feature.equals("posNgram_KON_ADJA_NN|top"))
					factor = 33.0;
				else if(feature.equals("posNgram_KON_ART_NN|top"))
					factor = 35.800000000000004;
				else if(feature.equals("posNgram_NE_ADJA_NN|top"))
					factor = 37.0;
				else if(feature.equals("posNgram_NE_FM_NE|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_NE_KOMMA_NE|top"))
					factor = 41.0;
				else if(feature.equals("posNgram_NE_NE_KOMMA|top"))
					factor = 40.0;
				else if(feature.equals("posNgram_NE_NE_NE|top"))
					factor = 14.333333333333334;
				else if(feature.equals("posNgram_NE_NE_NN|top"))
					factor = 43.0;
				else if(feature.equals("posNgram_NE_NE_SATZINTERN|top"))
					factor = 21.857142857142858;
				else if(feature.equals("posNgram_NE_NE_VVFIN|top"))
					factor = 56.0;
				else if(feature.equals("posNgram_NE_NN_SATZINTERN|top"))
					factor = 30.833333333333332;
				else if(feature.equals("posNgram_NE_SATZINTERN_NE|top"))
					factor = 29.666666666666668;
				else if(feature.equals("posNgram_NE_SATZINTERN_NN|top"))
					factor = 33.0;
				else if(feature.equals("posNgram_NN_ADJA_NN|top"))
					factor = 21.5;
				else if(feature.equals("posNgram_NN_ADV_ADV|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_NN_APPRART_NN|top"))
					factor = 29.0;
				else if(feature.equals("posNgram_NN_APPR_ADJA|top"))
					factor = 29.0;
				else if(feature.equals("posNgram_NN_APPR_ART|top"))
					factor = 22.25;
				else if(feature.equals("posNgram_NN_APPR_NE|top"))
					factor = 39.5;
				else if(feature.equals("posNgram_NN_APPR_NN|top"))
					factor = 36.33333333333333;
				else if(feature.equals("posNgram_NN_ART_ADJA|top"))
					factor = 23.6;
				else if(feature.equals("posNgram_NN_ART_NN|top"))
					factor = 12.833333333333334;
				else if(feature.equals("posNgram_NN_FM_NE|top"))
					factor = 43.47540983606557;
				else if(feature.equals("posNgram_NN_KOMMA_NN|top"))
					factor = 22.0;
				else if(feature.equals("posNgram_NN_KOMMA_PRELS|top"))
					factor = 36.0;
				else if(feature.equals("posNgram_NN_KON_ART|top"))
					factor = 35.800000000000004;
				else if(feature.equals("posNgram_NN_KON_NN|top"))
					factor = 25.857142857142858;
				else if(feature.equals("posNgram_NN_NE_NE|top"))
					factor = 21.5;
				else if(feature.equals("posNgram_NN_NE_NN|top"))
					factor = 29.333333333333336;
				else if(feature.equals("posNgram_NN_NN_ART|top"))
					factor = 52.49999999999999;
				else if(feature.equals("posNgram_NN_NN_CARD|top"))
					factor = 50.5;
				else if(feature.equals("posNgram_NN_NN_NE|top"))
					factor = 43.0;
				else if(feature.equals("posNgram_NN_NN_NN|top"))
					factor = 27.23076923076923;
				else if(feature.equals("posNgram_NN_NN_SATZINTERN|top"))
					factor = 32.25;
				else if(feature.equals("posNgram_NN_PTKVZ_SATZENDE|top"))
					factor = 37.0;
				else if(feature.equals("posNgram_NN_PTKZU_VVINF|top"))
					factor = 45.5;
				else if(feature.equals("posNgram_NN_SATZENDE_ADV|top"))
					factor = 52.0;
				else if(feature.equals("posNgram_NN_SATZENDE_ART|top"))
					factor = 36.75;
				else if(feature.equals("posNgram_NN_SATZINTERN_NE|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_NN_SATZINTERN_NN|top"))
					factor = 11.6;
				else if(feature.equals("posNgram_NN_SATZINTERN_VVFIN|top"))
					factor = 43.5;
				else if(feature.equals("posNgram_NN_VAFIN_ADV|top"))
					factor = 43.0;
				else if(feature.equals("posNgram_NN_VVFIN_ART|top"))
					factor = 49.00000000000001;
				else if(feature.equals("posNgram_NN_VVFIN_KOMMA|top"))
					factor = 41.0;
				else if(feature.equals("posNgram_NN_VVFIN_PPER|top"))
					factor = 41.5;
				else if(feature.equals("posNgram_NN_VVFIN_SATZENDE|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_NN_VVPP_SATZENDE|top"))
					factor = 41.5;
				else if(feature.equals("posNgram_PPOSAT_ADJA_NN|top"))
					factor = 31.666666666666664;
				else if(feature.equals("posNgram_PTKZU_VVINF_SATZENDE|top"))
					factor = 43.5;
				else if(feature.equals("posNgram_SATZENDE_ADV_VVFIN|top"))
					factor = 45.0;
				else if(feature.equals("posNgram_SATZENDE_ART_ADJA|top"))
					factor = 40.5;
				else if(feature.equals("posNgram_SATZENDE_ART_NN|top"))
					factor = 25.42857142857143;
				else if(feature.equals("posNgram_SATZENDE_PPER_VVFIN|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_SATZENDE|top"))
					factor = 16.57142857142857;
				else if(feature.equals("posNgram_SATZINTERN_ADJA_NN|top"))
					factor = 41.0;
				else if(feature.equals("posNgram_SATZINTERN_NE_NE|top"))
					factor = 26.750000000000004;
				else if(feature.equals("posNgram_SATZINTERN_NE_SATZINTERN|top"))
					factor = 22.8;
				else if(feature.equals("posNgram_SATZINTERN_NN_APPR|top"))
					factor = 44.0;
				else if(feature.equals("posNgram_SATZINTERN_NN_NE|top"))
					factor = 51.50000000000001;
				else if(feature.equals("posNgram_SATZINTERN_NN_NN|top"))
					factor = 40.333333333333336;
				else if(feature.equals("posNgram_SATZINTERN_NN_SATZINTERN|top"))
					factor = 19.333333333333332;
				else if(feature.equals("posNgram_SATZINTERN_NN_VVFIN|top"))
					factor = 31.0;
				else if(feature.equals("posNgram_VAFIN_ART_NN|top"))
					factor = 41.0;
				else if(feature.equals("posNgram_VVFIN_ART_NN|top"))
					factor = 42.75;
				else if(feature.equals("posNgram_VVFIN_PPER_ADV|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_XY_ADJA_XY|top"))
					factor = 21.0;
		}else if (this.normalizationMode == FeatureHandler.CALCULATED_MAXIMA_SMARTPHONE){
			 if(feature.equals("posNgram_ADJD_PTKZU_VVINF|gs"))
					factor = 29.0;
				else if(feature.equals("posNgram_ADV_PIS_ADV|gs"))
					factor = 68.0;
				else if(feature.equals("posNgram_ADV_SATZENDE_ADV|gs"))
					factor = 51.0;
				else if(feature.equals("posNgram_ADV_SATZENDE_KON|gs"))
					factor = 64.0;
				else if(feature.equals("posNgram_ADV_VMFIN_PPER|gs"))
					factor = 47.0;
				else if(feature.equals("posNgram_ADV_VVINF_SATZENDE|gs"))
					factor = 42.0;
				else if(feature.equals("posNgram_APPRART_NN_KON|gs"))
					factor = 43.0;
				else if(feature.equals("posNgram_APPRART_NN_SATZENDE|gs"))
					factor = 38.0;
				else if(feature.equals("posNgram_APPR_NE_NE|gs"))
					factor = 31.25;
				else if(feature.equals("posNgram_ART_NN_CARD|gs"))
					factor = 31.0;
				else if(feature.equals("posNgram_ART_NN_PTKVZ|gs"))
					factor = 42.0;
				else if(feature.equals("posNgram_ART_NN_PTKZU|gs"))
					factor = 34.0;
				else if(feature.equals("posNgram_ART_PIAT_NN|gs"))
					factor = 50.0;
				else if(feature.equals("posNgram_CARD_NN_CARD|gs"))
					factor = 45.0;
				else if(feature.equals("posNgram_CARD_NN_NE|gs"))
					factor = 22.0;
				else if(feature.equals("posNgram_KOMMA_NE_SATZINTERN|gs"))
					factor = 38.0;
				else if(feature.equals("posNgram_KOMMA_NN_CARD|gs"))
					factor = 65.4;
				else if(feature.equals("posNgram_KON_ADV_ADV|gs"))
					factor = 44.0;
				else if(feature.equals("posNgram_KON_KON_KON|gs"))
					factor = 9.714285714285715;
				else if(feature.equals("posNgram_KON_PPER_VVFIN|gs"))
					factor = 31.0;
				else if(feature.equals("posNgram_KOUS_PDS_ADV|gs"))
					factor = 76.0;
				else if(feature.equals("posNgram_NE_KON_NE|gs"))
					factor = 30.0;
				else if(feature.equals("posNgram_NE_SATZENDE_NE|gs"))
					factor = 24.0;
				else if(feature.equals("posNgram_NE_SATZINTERN_KON|gs"))
					factor = 29.0;
				else if(feature.equals("posNgram_NE_VVFIN_ADV|gs"))
					factor = 29.0;
				else if(feature.equals("posNgram_NE_VVFIN_SATZINTERN|gs"))
					factor = 60.5;
				else if(feature.equals("posNgram_NN_ADJD_ADJD|gs"))
					factor = 16.5;
				else if(feature.equals("posNgram_NN_ADJD_VVINF|gs"))
					factor = 32.5;
				else if(feature.equals("posNgram_NN_CARD_SATZENDE|gs"))
					factor = 34.0;
				else if(feature.equals("posNgram_NN_NE_SATZENDE|gs"))
					factor = 24.500000000000004;
				else if(feature.equals("posNgram_NN_PTKVZ_SATZINTERN|gs"))
					factor = 84.0;
				else if(feature.equals("posNgram_NN_SATZENDE_VVFIN|gs"))
					factor = 47.0;
				else if(feature.equals("posNgram_NN_SATZINTERN_KOMMA|gs"))
					factor = 27.0;
				else if(feature.equals("posNgram_NN_VVFIN_CARD|gs"))
					factor = 23.5;
				else if(feature.equals("posNgram_NN_VVINF_KON|gs"))
					factor = 45.0;
				else if(feature.equals("posNgram_NN_XY_CARD|gs"))
					factor = 86.5;
				else if(feature.equals("posNgram_PIAT_NN_APPR|gs"))
					factor = 40.0;
				else if(feature.equals("posNgram_PIAT_NN_VVFIN|gs"))
					factor = 34.0;
				else if(feature.equals("posNgram_PIS_PRF_ADV|gs"))
					factor = 41.5;
				else if(feature.equals("posNgram_PPER_PPER_ADV|gs"))
					factor = 62.0;
				else if(feature.equals("posNgram_PPER_PRF_ADJD|gs"))
					factor = 103.00000000000001;
				else if(feature.equals("posNgram_PPER_VAFIN_ADV|gs"))
					factor = 31.0;
				else if(feature.equals("posNgram_PPER_VVFIN_ADV|gs"))
					factor = 31.0;
				else if(feature.equals("posNgram_PPOSAT_ADJA_NN|gs"))
					factor = 30.0;
				else if(feature.equals("posNgram_PRELS_ART_NN|gs"))
					factor = 44.0;
				else if(feature.equals("posNgram_SATZENDE_CARD_SATZENDE|gs"))
					factor = 39.92307692307693;
				else if(feature.equals("posNgram_SATZENDE_KON_ADV|gs"))
					factor = 40.0;
				else if(feature.equals("posNgram_SATZENDE_NN_KOMMA|gs"))
					factor = 48.0;
				else if(feature.equals("posNgram_SATZENDE_PPER_VAIMP|gs"))
					factor = 108.0;
				else if(feature.equals("posNgram_SATZENDE_PROAV_VVFIN|gs"))
					factor = 44.0;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_NN|gs"))
					factor = 85.0;
				else if(feature.equals("posNgram_SATZINTERN_KOMMA_NN|gs"))
					factor = 65.4;
				else if(feature.equals("posNgram_SATZINTERN_NN_CARD|gs"))
					factor = 18.0;
				else if(feature.equals("posNgram_SATZINTERN_NN_NE|gs"))
					factor = 32.0;
				else if(feature.equals("posNgram_VAFIN_SATZENDE_ADJD|gs"))
					factor = 44.0;
				else if(feature.equals("posNgram_VVFIN_ADV_ADV|gs"))
					factor = 30.0;
				else if(feature.equals("posNgram_VVFIN_CARD_NN|gs"))
					factor = 44.0;
				else if(feature.equals("posNgram_VVFIN_NN_SATZENDE|gs"))
					factor = 33.0;
				else if(feature.equals("posNgram_VVFIN_SATZENDE_ADV|gs"))
					factor = 48.0;
				else if(feature.equals("posNgram_VVFIN_SATZENDE_SATZENDE|gs"))
					factor = 52.0;
				else if(feature.equals("posNgram_VVFIN_SATZENDE_VVFIN|gs"))
					factor = 37.0;
				else if(feature.equals("posNgram_VVFIN_SATZINTERN_NE|gs"))
					factor = 34.57142857142857;
				else if(feature.equals("posNgram_VVINF_SATZENDE_NE|gs"))
					factor = 54.0;
				else if(feature.equals("posNgram_VVINF_VMFIN_KON|gs"))
					factor = 60.0;
				else if(feature.equals("posNgram_VVINF_VMFIN_SATZINTERN|gs"))
					factor = 68.0;
				else if(feature.equals("posNgram_XY_CARD_SATZINTERN|gs"))
					factor = 86.5;
				else if(feature.equals("posNgram_ADJA_ADJA_NN|top"))
					factor = 15.0;
				else if(feature.equals("posNgram_ADJA_NN_ADJD|top"))
					factor = 21.5;
				else if(feature.equals("posNgram_ADJA_NN_APPR|top"))
					factor = 20.0;
				else if(feature.equals("posNgram_ADJA_NN_ART|top"))
					factor = 16.0;
				else if(feature.equals("posNgram_ADJA_NN_CARD|top"))
					factor = 25.5;
				else if(feature.equals("posNgram_ADJA_NN_KOMMA|top"))
					factor = 26.0;
				else if(feature.equals("posNgram_ADJA_NN_KON|top"))
					factor = 25.0;
				else if(feature.equals("posNgram_ADJA_NN_NE|top"))
					factor = 22.5;
				else if(feature.equals("posNgram_ADJA_NN_NN|top"))
					factor = 15.333333333333334;
				else if(feature.equals("posNgram_ADJA_NN_SATZENDE|top"))
					factor = 20.0;
				else if(feature.equals("posNgram_ADJA_NN_SATZINTERN|top"))
					factor = 15.0;
				else if(feature.equals("posNgram_ADJA_NN_VAFIN|top"))
					factor = 17.0;
				else if(feature.equals("posNgram_ADJA_NN_VVFIN|top"))
					factor = 16.0;
				else if(feature.equals("posNgram_ADJA_NN_VVPP|top"))
					factor = 14.5;
				else if(feature.equals("posNgram_ADJA_SATZINTERN_NN|top"))
					factor = 14.5;
				else if(feature.equals("posNgram_ADJD_ADJA_NN|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_ADJD_APPR_ART|top"))
					factor = 31.0;
				else if(feature.equals("posNgram_ADV_ADJA_NN|top"))
					factor = 18.0;
				else if(feature.equals("posNgram_ADV_ADV_ADJD|top"))
					factor = 40.5;
				else if(feature.equals("posNgram_ADV_ADV_ADV|top"))
					factor = 25.5;
				else if(feature.equals("posNgram_ADV_APPR_ART|top"))
					factor = 26.5;
				else if(feature.equals("posNgram_ADV_APPR_NN|top"))
					factor = 31.5;
				else if(feature.equals("posNgram_ADV_ART_ADJA|top"))
					factor = 14.5;
				else if(feature.equals("posNgram_ADV_ART_NN|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_APPRART_ADJA_NN|top"))
					factor = 23.5;
				else if(feature.equals("posNgram_APPR_ADJA_NN|top"))
					factor = 20.5;
				else if(feature.equals("posNgram_APPR_ART_ADJA|top"))
					factor = 20.0;
				else if(feature.equals("posNgram_APPR_ART_NE|top"))
					factor = 21.0;
				else if(feature.equals("posNgram_APPR_ART_NN|top"))
					factor = 11.25;
				else if(feature.equals("posNgram_APPR_CARD_NN|top"))
					factor = 17.75;
				else if(feature.equals("posNgram_APPR_NN_APPR|top"))
					factor = 32.5;
				else if(feature.equals("posNgram_APPR_NN_NN|top"))
					factor = 29.0;
				else if(feature.equals("posNgram_APPR_NN_SATZINTERN|top"))
					factor = 24.0;
				else if(feature.equals("posNgram_ART_ADJA_NN|top"))
					factor = 12.250000000000002;
				else if(feature.equals("posNgram_ART_NE_NE|top"))
					factor = 24.0;
				else if(feature.equals("posNgram_ART_NE_SATZINTERN|top"))
					factor = 18.5;
				else if(feature.equals("posNgram_ART_NN_ADJD|top"))
					factor = 16.5;
				else if(feature.equals("posNgram_ART_NN_ADV|top"))
					factor = 29.0;
				else if(feature.equals("posNgram_ART_NN_APPR|top"))
					factor = 14.333333333333334;
				else if(feature.equals("posNgram_ART_NN_ART|top"))
					factor = 18.0;
				else if(feature.equals("posNgram_ART_NN_KOMMA|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_ART_NN_KON|top"))
					factor = 14.0;
				else if(feature.equals("posNgram_ART_NN_NE|top"))
					factor = 16.333333333333332;
				else if(feature.equals("posNgram_ART_NN_NN|top"))
					factor = 14.0;
				else if(feature.equals("posNgram_ART_NN_SATZENDE|top"))
					factor = 27.0;
				else if(feature.equals("posNgram_ART_NN_SATZINTERN|top"))
					factor = 19.0;
				else if(feature.equals("posNgram_ART_NN_VAFIN|top"))
					factor = 27.666666666666668;
				else if(feature.equals("posNgram_ART_NN_VVFIN|top"))
					factor = 15.25;
				else if(feature.equals("posNgram_ART_NN_VVPP|top"))
					factor = 28.0;
				else if(feature.equals("posNgram_CARD_NN_SATZINTERN|top"))
					factor = 20.25;
				else if(feature.equals("posNgram_KOMMA_ART_NN|top"))
					factor = 23.0;
				else if(feature.equals("posNgram_KOMMA_KOUS_PPER|top"))
					factor = 34.0;
				else if(feature.equals("posNgram_KON_ART_NN|top"))
					factor = 29.0;
				else if(feature.equals("posNgram_NE_APPR_NN|top"))
					factor = 24.0;
				else if(feature.equals("posNgram_NE_NE_NE|top"))
					factor = 16.0;
				else if(feature.equals("posNgram_NE_SATZINTERN_NE|top"))
					factor = 5.958333333333333;
				else if(feature.equals("posNgram_NE_SATZINTERN_NN|top"))
					factor = 14.333333333333334;
				else if(feature.equals("posNgram_NN_ADJA_NN|top"))
					factor = 23.5;
				else if(feature.equals("posNgram_NN_ADV_ADV|top"))
					factor = 46.0;
				else if(feature.equals("posNgram_NN_APPRART_NN|top"))
					factor = 17.0;
				else if(feature.equals("posNgram_NN_APPR_ADJA|top"))
					factor = 23.0;
				else if(feature.equals("posNgram_NN_APPR_ART|top"))
					factor = 14.0;
				else if(feature.equals("posNgram_NN_APPR_NE|top"))
					factor = 15.25;
				else if(feature.equals("posNgram_NN_APPR_NN|top"))
					factor = 14.5;
				else if(feature.equals("posNgram_NN_ART_ADJA|top"))
					factor = 15.0;
				else if(feature.equals("posNgram_NN_ART_NE|top"))
					factor = 20.0;
				else if(feature.equals("posNgram_NN_ART_NN|top"))
					factor = 12.0;
				else if(feature.equals("posNgram_NN_CARD_NN|top"))
					factor = 32.5;
				else if(feature.equals("posNgram_NN_KOMMA_ART|top"))
					factor = 30.0;
				else if(feature.equals("posNgram_NN_KOMMA_NN|top"))
					factor = 23.0;
				else if(feature.equals("posNgram_NN_KOMMA_PRELS|top"))
					factor = 23.444444444444443;
				else if(feature.equals("posNgram_NN_KON_ART|top"))
					factor = 25.0;
				else if(feature.equals("posNgram_NN_KON_NN|top"))
					factor = 14.0;
				else if(feature.equals("posNgram_NN_NE_NE|top"))
					factor = 20.0;
				else if(feature.equals("posNgram_NN_NE_NN|top"))
					factor = 22.5;
				else if(feature.equals("posNgram_NN_NN_APPR|top"))
					factor = 36.0;
				else if(feature.equals("posNgram_NN_NN_ART|top"))
					factor = 16.666666666666668;
				else if(feature.equals("posNgram_NN_NN_NN|top"))
					factor = 12.125;
				else if(feature.equals("posNgram_NN_NN_SATZINTERN|top"))
					factor = 23.333333333333332;
				else if(feature.equals("posNgram_NN_PTKZU_VVINF|top"))
					factor = 17.0;
				else if(feature.equals("posNgram_NN_SATZENDE_ADV|top"))
					factor = 32.5;
				else if(feature.equals("posNgram_NN_SATZENDE_ART|top"))
					factor = 26.5;
				else if(feature.equals("posNgram_NN_SATZENDE_NE|top"))
					factor = 23.5;
				else if(feature.equals("posNgram_NN_SATZENDE_NN|top"))
					factor = 23.0;
				else if(feature.equals("posNgram_NN_SATZINTERN_NE|top"))
					factor = 17.0;
				else if(feature.equals("posNgram_NN_SATZINTERN_NN|top"))
					factor = 6.75;
				else if(feature.equals("posNgram_NN_VVFIN_APPR|top"))
					factor = 20.0;
				else if(feature.equals("posNgram_NN_VVFIN_ART|top"))
					factor = 14.5;
				else if(feature.equals("posNgram_NN_VVFIN_KOMMA|top"))
					factor = 39.0;
				else if(feature.equals("posNgram_NN_VVFIN_PPER|top"))
					factor = 24.0;
				else if(feature.equals("posNgram_NN_VVFIN_SATZENDE|top"))
					factor = 26.0;
				else if(feature.equals("posNgram_NN_VVINF_SATZENDE|top"))
					factor = 33.5;
				else if(feature.equals("posNgram_NN_VVPP_SATZENDE|top"))
					factor = 14.5;
				else if(feature.equals("posNgram_NN_VVPP_VAFIN|top"))
					factor = 32.0;
				else if(feature.equals("posNgram_PTKZU_VVINF_SATZENDE|top"))
					factor = 17.0;
				else if(feature.equals("posNgram_SATZENDE_ADJA_NN|top"))
					factor = 27.0;
				else if(feature.equals("posNgram_SATZENDE_ADV_VVFIN|top"))
					factor = 37.0;
				else if(feature.equals("posNgram_SATZENDE_ART_ADJA|top"))
					factor = 25.0;
				else if(feature.equals("posNgram_SATZENDE_ART_NN|top"))
					factor = 24.500000000000004;
				else if(feature.equals("posNgram_SATZENDE_CARD_NN|top"))
					factor = 25.317073170731707;
				else if(feature.equals("posNgram_SATZENDE_PPER_VVFIN|top"))
					factor = 26.5;
				else if(feature.equals("posNgram_SATZINTERN_ADJA_NN|top"))
					factor = 13.5;
				else if(feature.equals("posNgram_SATZINTERN_NE_SATZINTERN|top"))
					factor = 8.411764705882353;
				else if(feature.equals("posNgram_SATZINTERN_NN_APPR|top"))
					factor = 16.0;
				else if(feature.equals("posNgram_SATZINTERN_NN_KOMMA|top"))
					factor = 24.0;
				else if(feature.equals("posNgram_SATZINTERN_NN_NE|top"))
					factor = 32.0;
				else if(feature.equals("posNgram_SATZINTERN_NN_NN|top"))
					factor = 12.0;
				else if(feature.equals("posNgram_SATZINTERN_NN_SATZENDE|top"))
					factor = 23.5;
				else if(feature.equals("posNgram_SATZINTERN_NN_SATZINTERN|top"))
					factor = 6.75;
				else if(feature.equals("posNgram_SATZINTERN_NN_VVFIN|top"))
					factor = 28.0;
				else if(feature.equals("posNgram_VAFIN_ART_NN|top"))
					factor = 29.0;
				else if(feature.equals("posNgram_VVFIN_ART_ADJA|top"))
					factor = 29.0;
				else if(feature.equals("posNgram_VVFIN_ART_NN|top"))
					factor = 14.5;
				else if(feature.equals("posNgram_VVFIN_PPER_ADV|top"))
					factor = 20.5;
				else if(feature.equals("posNgram_VVPP_VAFIN_SATZENDE|top"))
					factor = 32.0;
		}else if (this.normalizationMode == FeatureHandler.CALCULATED_AVERAGE_MUSIC){
			 if(feature.equals("posNgram_ADJA_XY_ADJA|gs"))
					factor = 542.1891858119013;
				else if(feature.equals("posNgram_ADJA_XY_NN|gs"))
					factor = 746.3784423149322;
				else if(feature.equals("posNgram_ADJD_APPR_PDAT|gs"))
					factor = 5028.9470174622575;
				else if(feature.equals("posNgram_ADJD_NE_SATZINTERN|gs"))
					factor = 2875.2853135372807;
				else if(feature.equals("posNgram_ADV_SATZENDE_PPER|gs"))
					factor = 7015.593719693641;
				else if(feature.equals("posNgram_ADV_SATZENDE_SATZENDE|gs"))
					factor = 5663.392431847408;
				else if(feature.equals("posNgram_CARD_NN_FM|gs"))
					factor = 23546.55555016682;
				else if(feature.equals("posNgram_CARD_PDAT_NN|gs"))
					factor = 5653.997649443615;
				else if(feature.equals("posNgram_CARD_PPER_VAFIN|gs"))
					factor = 5521.739514444119;
				else if(feature.equals("posNgram_CARD_SATZENDE_CARD|gs"))
					factor = 9158.69644975593;
				else if(feature.equals("posNgram_CARD_SATZINTERN_CARD|gs"))
					factor = 1479.6805397576425;
				else if(feature.equals("posNgram_FM_XY_ADJA|gs"))
					factor = 1060.9370510552567;
				else if(feature.equals("posNgram_FM_XY_FM|gs"))
					factor = 3002.1150234853158;
				else if(feature.equals("posNgram_FM_XY_NE|gs"))
					factor = 4302.776219916368;
				else if(feature.equals("posNgram_KOMMA_VMFIN_PPER|gs"))
					factor = 6351.304939157511;
				else if(feature.equals("posNgram_KON_KON_KON|gs"))
					factor = 2567.0439774696706;
				else if(feature.equals("posNgram_NE_FM_ADJA|gs"))
					factor = 15750.600240417229;
				else if(feature.equals("posNgram_NE_XY_ADJA|gs"))
					factor = 3019.4653947028337;
				else if(feature.equals("posNgram_NN_CARD_PDAT|gs"))
					factor = 5452.398046366435;
				else if(feature.equals("posNgram_NN_CARD_PPER|gs"))
					factor = 2088.6439278420203;
				else if(feature.equals("posNgram_SATZENDE_NN_PRF|gs"))
					factor = 5865.648680836531;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_ADJA|gs"))
					factor = 7994.199157956736;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_ADJD|gs"))
					factor = 5452.796766484072;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_ADV|gs"))
					factor = 3253.1721861833253;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_PPER|gs"))
					factor = 6500.329064125007;
				else if(feature.equals("posNgram_SATZINTERN_ADJA_XY|gs"))
					factor = 553.2844218942881;
				else if(feature.equals("posNgram_SATZINTERN_CARD_ADJA|gs"))
					factor = 4917.126667631398;
				else if(feature.equals("posNgram_SATZINTERN_KON_PPER|gs"))
					factor = 6625.46529746627;
				else if(feature.equals("posNgram_SATZINTERN_NN_XY|gs"))
					factor = 721.7566792828372;
				else if(feature.equals("posNgram_VAFIN_ADV_CARD|gs"))
					factor = 8114.264131543513;
				else if(feature.equals("posNgram_VAFIN_NN_PRF|gs"))
					factor = 4591.421136004726;
				else if(feature.equals("posNgram_VAFIN_SATZENDE_SATZENDE|gs"))
					factor = 5396.581601675776;
				else if(feature.equals("posNgram_VVINF_SATZENDE_SATZENDE|gs"))
					factor = 4086.7979461679256;
				else if(feature.equals("posNgram_VVPP_KOMMA_KOUI|gs"))
					factor = 4810.437793178187;
				else if(feature.equals("posNgram_XY_ADJA_XY|gs"))
					factor = 347.7289436131132;
				else if(feature.equals("posNgram_XY_APPR_XY|gs"))
					factor = 5954.859842173802;
				else if(feature.equals("posNgram_XY_FM_XY|gs"))
					factor = 492.9517369808031;
				else if(feature.equals("posNgram_XY_NE_NE|gs"))
					factor = 6174.341880729735;
				else if(feature.equals("posNgram_XY_NE_SATZINTERN|gs"))
					factor = 960.1004310829837;
				else if(feature.equals("posNgram_XY_NN_SATZINTERN|gs"))
					factor = 573.656960868327;
				else if(feature.equals("posNgram_XY_NN_XY|gs"))
					factor = 592.941123347944;
				else if(feature.equals("posNgram_XY_VVFIN_ART|gs"))
					factor = 5781.840691863249;
				else if(feature.equals("posNgram_XY_XY_SATZINTERN|gs"))
					factor = 8583.787933526011;
				else if(feature.equals("posNgram_XY_XY_XY|gs"))
					factor = 1841.806374834851;
				else if(feature.equals("posNgram_ADJA_ADJA_NN|top"))
					factor = 213.49025182950936;
				else if(feature.equals("posNgram_ADJA_NN_ADJA|top"))
					factor = 512.2389164022275;
				else if(feature.equals("posNgram_ADJA_NN_ADJD|top"))
					factor = 470.4627431362841;
				else if(feature.equals("posNgram_ADJA_NN_ADV|top"))
					factor = 296.2529461617597;
				else if(feature.equals("posNgram_ADJA_NN_APPR|top"))
					factor = 99.28867299902014;
				else if(feature.equals("posNgram_ADJA_NN_ART|top"))
					factor = 152.1659372151451;
				else if(feature.equals("posNgram_ADJA_NN_KOMMA|top"))
					factor = 123.48123147908278;
				else if(feature.equals("posNgram_ADJA_NN_KON|top"))
					factor = 219.73215225607856;
				else if(feature.equals("posNgram_ADJA_NN_NE|top"))
					factor = 388.5576827800375;
				else if(feature.equals("posNgram_ADJA_NN_NN|top"))
					factor = 184.5685674386355;
				else if(feature.equals("posNgram_ADJA_NN_SATZENDE|top"))
					factor = 107.07777426592048;
				else if(feature.equals("posNgram_ADJA_NN_SATZINTERN|top"))
					factor = 84.7511488655105;
				else if(feature.equals("posNgram_ADJA_NN_VAFIN|top"))
					factor = 321.06563798083897;
				else if(feature.equals("posNgram_ADJA_NN_VVFIN|top"))
					factor = 140.65645879323768;
				else if(feature.equals("posNgram_ADJA_SATZINTERN_NN|top"))
					factor = 256.67238056381296;
				else if(feature.equals("posNgram_ADJD_ADJA_NN|top"))
					factor = 204.91823203314422;
				else if(feature.equals("posNgram_ADV_ADJA_NN|top"))
					factor = 200.02325484659485;
				else if(feature.equals("posNgram_ADV_ADV_ADJD|top"))
					factor = 277.69085419818936;
				else if(feature.equals("posNgram_ADV_ADV_ADV|top"))
					factor = 276.0906114594364;
				else if(feature.equals("posNgram_ADV_ADV_APPR|top"))
					factor = 341.31743569136074;
				else if(feature.equals("posNgram_ADV_APPR_ART|top"))
					factor = 194.0031715416817;
				else if(feature.equals("posNgram_ADV_ART_ADJA|top"))
					factor = 263.0722542490801;
				else if(feature.equals("posNgram_ADV_ART_NN|top"))
					factor = 165.83022214008204;
				else if(feature.equals("posNgram_APPRART_ADJA_NN|top"))
					factor = 294.04393263637076;
				else if(feature.equals("posNgram_APPR_ADJA_NN|top"))
					factor = 135.49670525784995;
				else if(feature.equals("posNgram_APPR_ART_ADJA|top"))
					factor = 92.44805041216311;
				else if(feature.equals("posNgram_APPR_ART_NN|top"))
					factor = 48.179061065041246;
				else if(feature.equals("posNgram_APPR_NE_NE|top"))
					factor = 337.026260833071;
				else if(feature.equals("posNgram_APPR_PDAT_NN|top"))
					factor = 400.09918299824994;
				else if(feature.equals("posNgram_APPR_PPOSAT_NN|top"))
					factor = 253.30138498449676;
				else if(feature.equals("posNgram_ART_ADJA_NN|top"))
					factor = 31.014312691432078;
				else if(feature.equals("posNgram_ART_NN_ADV|top"))
					factor = 199.58784398537375;
				else if(feature.equals("posNgram_ART_NN_APPR|top"))
					factor = 91.3604146152122;
				else if(feature.equals("posNgram_ART_NN_ART|top"))
					factor = 139.93235680129365;
				else if(feature.equals("posNgram_ART_NN_KOMMA|top"))
					factor = 173.70003334793856;
				else if(feature.equals("posNgram_ART_NN_KON|top"))
					factor = 362.0021960946007;
				else if(feature.equals("posNgram_ART_NN_NN|top"))
					factor = 181.9444377186602;
				else if(feature.equals("posNgram_ART_NN_SATZENDE|top"))
					factor = 168.65423465949377;
				else if(feature.equals("posNgram_ART_NN_SATZINTERN|top"))
					factor = 129.2879092694369;
				else if(feature.equals("posNgram_ART_NN_VAFIN|top"))
					factor = 292.1705281700395;
				else if(feature.equals("posNgram_ART_NN_VVFIN|top"))
					factor = 151.94538985120562;
				else if(feature.equals("posNgram_FM_NN_NN|top"))
					factor = 1097.9202704468296;
				else if(feature.equals("posNgram_KOMMA_ADJA_NN|top"))
					factor = 354.134583458182;
				else if(feature.equals("posNgram_KOMMA_ART_NN|top"))
					factor = 330.5670654928489;
				else if(feature.equals("posNgram_KOMMA_KOUS_PPER|top"))
					factor = 307.51801313393963;
				else if(feature.equals("posNgram_KOMMA_NE_NE|top"))
					factor = 691.7934225023324;
				else if(feature.equals("posNgram_KON_ADJA_NN|top"))
					factor = 329.1715472394607;
				else if(feature.equals("posNgram_KON_ART_NN|top"))
					factor = 324.19381693869894;
				else if(feature.equals("posNgram_NE_ADJA_NN|top"))
					factor = 534.1211774988378;
				else if(feature.equals("posNgram_NE_FM_NE|top"))
					factor = 858.8144041724647;
				else if(feature.equals("posNgram_NE_KOMMA_NE|top"))
					factor = 517.7516022413162;
				else if(feature.equals("posNgram_NE_NE_KOMMA|top"))
					factor = 476.96863245602833;
				else if(feature.equals("posNgram_NE_NE_NE|top"))
					factor = 312.877564281255;
				else if(feature.equals("posNgram_NE_NE_NN|top"))
					factor = 358.1270756530251;
				else if(feature.equals("posNgram_NE_NE_SATZINTERN|top"))
					factor = 119.32280925700478;
				else if(feature.equals("posNgram_NE_NE_VVFIN|top"))
					factor = 498.19893010517944;
				else if(feature.equals("posNgram_NE_NN_SATZINTERN|top"))
					factor = 297.5292295577515;
				else if(feature.equals("posNgram_NE_SATZINTERN_NE|top"))
					factor = 226.15775001987663;
				else if(feature.equals("posNgram_NE_SATZINTERN_NN|top"))
					factor = 116.23165001205388;
				else if(feature.equals("posNgram_NN_ADJA_NN|top"))
					factor = 149.37204304006403;
				else if(feature.equals("posNgram_NN_ADV_ADV|top"))
					factor = 234.5807385453111;
				else if(feature.equals("posNgram_NN_APPRART_NN|top"))
					factor = 186.64943922665483;
				else if(feature.equals("posNgram_NN_APPR_ADJA|top"))
					factor = 303.17710082793906;
				else if(feature.equals("posNgram_NN_APPR_ART|top"))
					factor = 80.18606494908195;
				else if(feature.equals("posNgram_NN_APPR_NE|top"))
					factor = 200.70927745012042;
				else if(feature.equals("posNgram_NN_APPR_NN|top"))
					factor = 128.43989846676456;
				else if(feature.equals("posNgram_NN_ART_ADJA|top"))
					factor = 134.2331762822318;
				else if(feature.equals("posNgram_NN_ART_NN|top"))
					factor = 64.80123564268537;
				else if(feature.equals("posNgram_NN_FM_NE|top"))
					factor = 720.6871856847864;
				else if(feature.equals("posNgram_NN_KOMMA_NN|top"))
					factor = 243.7225787866499;
				else if(feature.equals("posNgram_NN_KOMMA_PRELS|top"))
					factor = 159.66693683207302;
				else if(feature.equals("posNgram_NN_KON_ART|top"))
					factor = 368.9001102782357;
				else if(feature.equals("posNgram_NN_KON_NN|top"))
					factor = 148.5769253428328;
				else if(feature.equals("posNgram_NN_NE_NE|top"))
					factor = 224.00436418965333;
				else if(feature.equals("posNgram_NN_NE_NN|top"))
					factor = 315.8003931859343;
				else if(feature.equals("posNgram_NN_NN_ART|top"))
					factor = 366.6928392958566;
				else if(feature.equals("posNgram_NN_NN_CARD|top"))
					factor = 508.34497864397275;
				else if(feature.equals("posNgram_NN_NN_NE|top"))
					factor = 529.3618633207603;
				else if(feature.equals("posNgram_NN_NN_NN|top"))
					factor = 253.96066284128858;
				else if(feature.equals("posNgram_NN_NN_SATZINTERN|top"))
					factor = 196.55107471353176;
				else if(feature.equals("posNgram_NN_PTKVZ_SATZENDE|top"))
					factor = 342.6594596878458;
				else if(feature.equals("posNgram_NN_PTKZU_VVINF|top"))
					factor = 282.5134306855829;
				else if(feature.equals("posNgram_NN_SATZENDE_ADV|top"))
					factor = 283.3658193894236;
				else if(feature.equals("posNgram_NN_SATZENDE_ART|top"))
					factor = 265.99102342698666;
				else if(feature.equals("posNgram_NN_SATZINTERN_NE|top"))
					factor = 191.58085612655688;
				else if(feature.equals("posNgram_NN_SATZINTERN_NN|top"))
					factor = 49.94246934783659;
				else if(feature.equals("posNgram_NN_SATZINTERN_VVFIN|top"))
					factor = 321.63686282451437;
				else if(feature.equals("posNgram_NN_VAFIN_ADV|top"))
					factor = 388.9677391423947;
				else if(feature.equals("posNgram_NN_VVFIN_ART|top"))
					factor = 339.61744094062186;
				else if(feature.equals("posNgram_NN_VVFIN_KOMMA|top"))
					factor = 255.46549839709584;
				else if(feature.equals("posNgram_NN_VVFIN_PPER|top"))
					factor = 386.90159789581094;
				else if(feature.equals("posNgram_NN_VVFIN_SATZENDE|top"))
					factor = 210.25048548727816;
				else if(feature.equals("posNgram_NN_VVPP_SATZENDE|top"))
					factor = 322.59901862433543;
				else if(feature.equals("posNgram_PPOSAT_ADJA_NN|top"))
					factor = 222.6237418353466;
				else if(feature.equals("posNgram_PTKZU_VVINF_SATZENDE|top"))
					factor = 334.32795107324745;
				else if(feature.equals("posNgram_SATZENDE_ADV_VVFIN|top"))
					factor = 300.3384132670975;
				else if(feature.equals("posNgram_SATZENDE_ART_ADJA|top"))
					factor = 319.70716849335463;
				else if(feature.equals("posNgram_SATZENDE_ART_NN|top"))
					factor = 136.62018710809235;
				else if(feature.equals("posNgram_SATZENDE_PPER_VVFIN|top"))
					factor = 462.8956828924786;
				else if(feature.equals("posNgram_SATZENDE_SATZENDE_SATZENDE|top"))
					factor = 283.9878467861084;
				else if(feature.equals("posNgram_SATZINTERN_ADJA_NN|top"))
					factor = 259.4120301670905;
				else if(feature.equals("posNgram_SATZINTERN_NE_NE|top"))
					factor = 241.52791642042024;
				else if(feature.equals("posNgram_SATZINTERN_NE_SATZINTERN|top"))
					factor = 150.2796378708114;
				else if(feature.equals("posNgram_SATZINTERN_NN_APPR|top"))
					factor = 308.4866361647851;
				else if(feature.equals("posNgram_SATZINTERN_NN_NE|top"))
					factor = 270.2556345817811;
				else if(feature.equals("posNgram_SATZINTERN_NN_NN|top"))
					factor = 190.06034913102025;
				else if(feature.equals("posNgram_SATZINTERN_NN_SATZINTERN|top"))
					factor = 124.65692752344687;
				else if(feature.equals("posNgram_SATZINTERN_NN_VVFIN|top"))
					factor = 334.3726247853951;
				else if(feature.equals("posNgram_VAFIN_ART_NN|top"))
					factor = 308.4605909302076;
				else if(feature.equals("posNgram_VVFIN_ART_NN|top"))
					factor = 177.0432736155072;
				else if(feature.equals("posNgram_VVFIN_PPER_ADV|top"))
					factor = 412.9544998176086;
				else if(feature.equals("posNgram_XY_ADJA_XY|top"))
					factor = 347.7289436131132;
				else System.err.println("Fehler bei POSNgram "+feature);
			 
		}else if (this.normalizationMode == FeatureHandler.CALCULATED_AVERAGE_SMARTPHONE){
			if(feature.equals("posNgram_ADJD_PTKZU_VVINF|gs"))
				factor = 1275.7323634565244;
			else if(feature.equals("posNgram_ADV_PIS_ADV|gs"))
				factor = 5018.228319191709;
			else if(feature.equals("posNgram_ADV_SATZENDE_ADV|gs"))
				factor = 2730.7315701965817;
			else if(feature.equals("posNgram_ADV_SATZENDE_KON|gs"))
				factor = 6486.950805541771;
			else if(feature.equals("posNgram_ADV_VMFIN_PPER|gs"))
				factor = 3178.2951002320865;
			else if(feature.equals("posNgram_ADV_VVINF_SATZENDE|gs"))
				factor = 1528.6999080967955;
			else if(feature.equals("posNgram_APPRART_NN_KON|gs"))
				factor = 1397.3893852554538;
			else if(feature.equals("posNgram_APPRART_NN_SATZENDE|gs"))
				factor = 541.42850265304;
			else if(feature.equals("posNgram_APPR_NE_NE|gs"))
				factor = 507.2923914152615;
			else if(feature.equals("posNgram_ART_NN_CARD|gs"))
				factor = 961.487382927125;
			else if(feature.equals("posNgram_ART_NN_PTKVZ|gs"))
				factor = 1175.0643264777623;
			else if(feature.equals("posNgram_ART_NN_PTKZU|gs"))
				factor = 1073.9659440871255;
			else if(feature.equals("posNgram_ART_PIAT_NN|gs"))
				factor = 874.9995865909245;
			else if(feature.equals("posNgram_CARD_NN_CARD|gs"))
				factor = 2512.0382823929317;
			else if(feature.equals("posNgram_CARD_NN_NE|gs"))
				factor = 1326.469022296223;
			else if(feature.equals("posNgram_KOMMA_NE_SATZINTERN|gs"))
				factor = 1462.231323267664;
			else if(feature.equals("posNgram_KOMMA_NN_CARD|gs"))
				factor = 6829.868132269104;
			else if(feature.equals("posNgram_KON_ADV_ADV|gs"))
				factor = 1322.5131005764972;
			else if(feature.equals("posNgram_KON_KON_KON|gs"))
				factor = 1253.5629714794395;
			else if(feature.equals("posNgram_KON_PPER_VVFIN|gs"))
				factor = 1577.9302105303334;
			else if(feature.equals("posNgram_KOUS_PDS_ADV|gs"))
				factor = 6277.588856774442;
			else if(feature.equals("posNgram_NE_KON_NE|gs"))
				factor = 588.5438664794339;
			else if(feature.equals("posNgram_NE_SATZENDE_NE|gs"))
				factor = 1049.999988361352;
			else if(feature.equals("posNgram_NE_SATZINTERN_KON|gs"))
				factor = 2135.086565474499;
			else if(feature.equals("posNgram_NE_VVFIN_ADV|gs"))
				factor = 1203.7094644465358;
			else if(feature.equals("posNgram_NE_VVFIN_SATZINTERN|gs"))
				factor = 7062.678004860205;
			else if(feature.equals("posNgram_NN_ADJD_ADJD|gs"))
				factor = 929.8426054866751;
			else if(feature.equals("posNgram_NN_ADJD_VVINF|gs"))
				factor = 1176.0797671906084;
			else if(feature.equals("posNgram_NN_CARD_SATZENDE|gs"))
				factor = 1322.992980595307;
			else if(feature.equals("posNgram_NN_NE_SATZENDE|gs"))
				factor = 519.2902723471187;
			else if(feature.equals("posNgram_NN_PTKVZ_SATZINTERN|gs"))
				factor = 6440.73774923355;
			else if(feature.equals("posNgram_NN_SATZENDE_VVFIN|gs"))
				factor = 1340.4098202548576;
			else if(feature.equals("posNgram_NN_SATZINTERN_KOMMA|gs"))
				factor = 1836.5731945491984;
			else if(feature.equals("posNgram_NN_VVFIN_CARD|gs"))
				factor = 1327.9440820975426;
			else if(feature.equals("posNgram_NN_VVINF_KON|gs"))
				factor = 1128.8600972480033;
			else if(feature.equals("posNgram_NN_XY_CARD|gs"))
				factor = 5374.999488966281;
			else if(feature.equals("posNgram_PIAT_NN_APPR|gs"))
				factor = 919.16651417806;
			else if(feature.equals("posNgram_PIAT_NN_VVFIN|gs"))
				factor = 989.0739952665294;
			else if(feature.equals("posNgram_PIS_PRF_ADV|gs"))
				factor = 3024.7479246570174;
			else if(feature.equals("posNgram_PPER_PPER_ADV|gs"))
				factor = 5324.081732351959;
			else if(feature.equals("posNgram_PPER_PRF_ADJD|gs"))
				factor = 5462.204432479351;
			else if(feature.equals("posNgram_PPER_VAFIN_ADV|gs"))
				factor = 1179.2973298521295;
			else if(feature.equals("posNgram_PPER_VVFIN_ADV|gs"))
				factor = 1060.3484322391416;
			else if(feature.equals("posNgram_PPOSAT_ADJA_NN|gs"))
				factor = 515.1826929575124;
			else if(feature.equals("posNgram_PRELS_ART_NN|gs"))
				factor = 1022.02017076381;
			else if(feature.equals("posNgram_SATZENDE_CARD_SATZENDE|gs"))
				factor = 5105.0154497886415;
			else if(feature.equals("posNgram_SATZENDE_KON_ADV|gs"))
				factor = 1057.6093882086254;
			else if(feature.equals("posNgram_SATZENDE_NN_KOMMA|gs"))
				factor = 1198.1605035061084;
			else if(feature.equals("posNgram_SATZENDE_PPER_VAIMP|gs"))
				factor = 8051.377616923871;
			else if(feature.equals("posNgram_SATZENDE_PROAV_VVFIN|gs"))
				factor = 1304.4036339893528;
			else if(feature.equals("posNgram_SATZENDE_SATZENDE_NN|gs"))
				factor = 9980.635041563559;
			else if(feature.equals("posNgram_SATZINTERN_KOMMA_NN|gs"))
				factor = 5268.478858937169;
			else if(feature.equals("posNgram_SATZINTERN_NN_CARD|gs"))
				factor = 967.339560311563;
			else if(feature.equals("posNgram_SATZINTERN_NN_NE|gs"))
				factor = 376.1078682790632;
			else if(feature.equals("posNgram_VAFIN_SATZENDE_ADJD|gs"))
				factor = 5237.658669314316;
			else if(feature.equals("posNgram_VVFIN_ADV_ADV|gs"))
				factor = 513.4849446929791;
			else if(feature.equals("posNgram_VVFIN_CARD_NN|gs"))
				factor = 2037.8458316347928;
			else if(feature.equals("posNgram_VVFIN_NN_SATZENDE|gs"))
				factor = 880.2183915720575;
			else if(feature.equals("posNgram_VVFIN_SATZENDE_ADV|gs"))
				factor = 991.5772596337229;
			else if(feature.equals("posNgram_VVFIN_SATZENDE_SATZENDE|gs"))
				factor = 4084.87166638955;
			else if(feature.equals("posNgram_VVFIN_SATZENDE_VVFIN|gs"))
				factor = 4243.036973571339;
			else if(feature.equals("posNgram_VVFIN_SATZINTERN_NE|gs"))
				factor = 3635.9032572365527;
			else if(feature.equals("posNgram_VVINF_SATZENDE_NE|gs"))
				factor = 1648.1244419837708;
			else if(feature.equals("posNgram_VVINF_VMFIN_KON|gs"))
				factor = 5153.37483536483;
			else if(feature.equals("posNgram_VVINF_VMFIN_SATZINTERN|gs"))
				factor = 6346.096688056671;
			else if(feature.equals("posNgram_XY_CARD_SATZINTERN|gs"))
				factor = 4966.649325909629;
			else if(feature.equals("posNgram_ADJA_ADJA_NN|top"))
				factor = 165.9803925824535;
			else if(feature.equals("posNgram_ADJA_NN_ADJD|top"))
				factor = 319.67413096332774;
			else if(feature.equals("posNgram_ADJA_NN_APPR|top"))
				factor = 100.32728632962849;
			else if(feature.equals("posNgram_ADJA_NN_ART|top"))
				factor = 169.22812832839443;
			else if(feature.equals("posNgram_ADJA_NN_CARD|top"))
				factor = 375.4710655492636;
			else if(feature.equals("posNgram_ADJA_NN_KOMMA|top"))
				factor = 198.99379200008218;
			else if(feature.equals("posNgram_ADJA_NN_KON|top"))
				factor = 302.24462622568245;
			else if(feature.equals("posNgram_ADJA_NN_NE|top"))
				factor = 238.73331234554604;
			else if(feature.equals("posNgram_ADJA_NN_NN|top"))
				factor = 125.4225322281995;
			else if(feature.equals("posNgram_ADJA_NN_SATZENDE|top"))
				factor = 121.51505342018957;
			else if(feature.equals("posNgram_ADJA_NN_SATZINTERN|top"))
				factor = 83.95816871394668;
			else if(feature.equals("posNgram_ADJA_NN_VAFIN|top"))
				factor = 282.2201606288823;
			else if(feature.equals("posNgram_ADJA_NN_VVFIN|top"))
				factor = 132.44076030933834;
			else if(feature.equals("posNgram_ADJA_NN_VVPP|top"))
				factor = 306.9829050525947;
			else if(feature.equals("posNgram_ADJA_SATZINTERN_NN|top"))
				factor = 107.37297535123953;
			else if(feature.equals("posNgram_ADJD_ADJA_NN|top"))
				factor = 328.21782691961437;
			else if(feature.equals("posNgram_ADJD_APPR_ART|top"))
				factor = 383.9280365136979;
			else if(feature.equals("posNgram_ADV_ADJA_NN|top"))
				factor = 314.4868394274884;
			else if(feature.equals("posNgram_ADV_ADV_ADJD|top"))
				factor = 435.74284078483623;
			else if(feature.equals("posNgram_ADV_ADV_ADV|top"))
				factor = 386.85916460120865;
			else if(feature.equals("posNgram_ADV_APPR_ART|top"))
				factor = 206.5541940361163;
			else if(feature.equals("posNgram_ADV_APPR_NN|top"))
				factor = 346.63808018815644;
			else if(feature.equals("posNgram_ADV_ART_ADJA|top"))
				factor = 273.584367400614;
			else if(feature.equals("posNgram_ADV_ART_NN|top"))
				factor = 181.84479353147486;
			else if(feature.equals("posNgram_APPRART_ADJA_NN|top"))
				factor = 190.76502563807057;
			else if(feature.equals("posNgram_APPR_ADJA_NN|top"))
				factor = 144.6154549252812;
			else if(feature.equals("posNgram_APPR_ART_ADJA|top"))
				factor = 91.39475153460306;
			else if(feature.equals("posNgram_APPR_ART_NE|top"))
				factor = 249.01820001148764;
			else if(feature.equals("posNgram_APPR_ART_NN|top"))
				factor = 40.7343253526305;
			else if(feature.equals("posNgram_APPR_CARD_NN|top"))
				factor = 345.9352892559619;
			else if(feature.equals("posNgram_APPR_NN_APPR|top"))
				factor = 335.1256013450677;
			else if(feature.equals("posNgram_APPR_NN_NN|top"))
				factor = 388.5563829018796;
			else if(feature.equals("posNgram_APPR_NN_SATZINTERN|top"))
				factor = 383.0148359081152;
			else if(feature.equals("posNgram_ART_ADJA_NN|top"))
				factor = 31.14414547920069;
			else if(feature.equals("posNgram_ART_NE_NE|top"))
				factor = 413.2336975417648;
			else if(feature.equals("posNgram_ART_NE_SATZINTERN|top"))
				factor = 251.21910375630034;
			else if(feature.equals("posNgram_ART_NN_ADJD|top"))
				factor = 317.54951322071247;
			else if(feature.equals("posNgram_ART_NN_ADV|top"))
				factor = 247.31389564315654;
			else if(feature.equals("posNgram_ART_NN_APPR|top"))
				factor = 83.64150396643606;
			else if(feature.equals("posNgram_ART_NN_ART|top"))
				factor = 117.243202903694;
			else if(feature.equals("posNgram_ART_NN_KOMMA|top"))
				factor = 233.78229721263523;
			else if(feature.equals("posNgram_ART_NN_KON|top"))
				factor = 303.6034411380102;
			else if(feature.equals("posNgram_ART_NN_NE|top"))
				factor = 191.9149492150601;
			else if(feature.equals("posNgram_ART_NN_NN|top"))
				factor = 132.84280826872364;
			else if(feature.equals("posNgram_ART_NN_SATZENDE|top"))
				factor = 178.72142863878656;
			else if(feature.equals("posNgram_ART_NN_SATZINTERN|top"))
				factor = 98.8186996882834;
			else if(feature.equals("posNgram_ART_NN_VAFIN|top"))
				factor = 279.85121509311614;
			else if(feature.equals("posNgram_ART_NN_VVFIN|top"))
				factor = 140.51394264228196;
			else if(feature.equals("posNgram_ART_NN_VVPP|top"))
				factor = 267.6413970284086;
			else if(feature.equals("posNgram_CARD_NN_SATZINTERN|top"))
				factor = 444.2274009798171;
			else if(feature.equals("posNgram_KOMMA_ART_NN|top"))
				factor = 325.8175779637679;
			else if(feature.equals("posNgram_KOMMA_KOUS_PPER|top"))
				factor = 449.05029486693644;
			else if(feature.equals("posNgram_KON_ART_NN|top"))
				factor = 302.41656709709656;
			else if(feature.equals("posNgram_NE_APPR_NN|top"))
				factor = 381.51833502131086;
			else if(feature.equals("posNgram_NE_NE_NE|top"))
				factor = 465.4974534931138;
			else if(feature.equals("posNgram_NE_SATZINTERN_NE|top"))
				factor = 275.77123439586984;
			else if(feature.equals("posNgram_NE_SATZINTERN_NN|top"))
				factor = 76.15136423837909;
			else if(feature.equals("posNgram_NN_ADJA_NN|top"))
				factor = 114.8230277521225;
			else if(feature.equals("posNgram_NN_ADV_ADV|top"))
				factor = 395.1334971281199;
			else if(feature.equals("posNgram_NN_APPRART_NN|top"))
				factor = 134.98087644430794;
			else if(feature.equals("posNgram_NN_APPR_ADJA|top"))
				factor = 232.09355789417864;
			else if(feature.equals("posNgram_NN_APPR_ART|top"))
				factor = 62.51399514384522;
			else if(feature.equals("posNgram_NN_APPR_NE|top"))
				factor = 134.87584012578827;
			else if(feature.equals("posNgram_NN_APPR_NN|top"))
				factor = 79.73846842152186;
			else if(feature.equals("posNgram_NN_ART_ADJA|top"))
				factor = 98.0683197002971;
			else if(feature.equals("posNgram_NN_ART_NE|top"))
				factor = 244.8155728406754;
			else if(feature.equals("posNgram_NN_ART_NN|top"))
				factor = 47.8037639507795;
			else if(feature.equals("posNgram_NN_CARD_NN|top"))
				factor = 503.4755931795483;
			else if(feature.equals("posNgram_NN_KOMMA_ART|top"))
				factor = 476.78849805405076;
			else if(feature.equals("posNgram_NN_KOMMA_NN|top"))
				factor = 226.5269987571311;
			else if(feature.equals("posNgram_NN_KOMMA_PRELS|top"))
				factor = 219.66561282821843;
			else if(feature.equals("posNgram_NN_KON_ART|top"))
				factor = 362.30454061296723;
			else if(feature.equals("posNgram_NN_KON_NN|top"))
				factor = 154.01925605548809;
			else if(feature.equals("posNgram_NN_NE_NE|top"))
				factor = 333.15437815556743;
			else if(feature.equals("posNgram_NN_NE_NN|top"))
				factor = 325.6613845573287;
			else if(feature.equals("posNgram_NN_NN_APPR|top"))
				factor = 367.13497759228784;
			else if(feature.equals("posNgram_NN_NN_ART|top"))
				factor = 144.72947483664717;
			else if(feature.equals("posNgram_NN_NN_NN|top"))
				factor = 207.0654407426405;
			else if(feature.equals("posNgram_NN_NN_SATZINTERN|top"))
				factor = 383.1517145516409;
			else if(feature.equals("posNgram_NN_PTKZU_VVINF|top"))
				factor = 272.1016328191804;
			else if(feature.equals("posNgram_NN_SATZENDE_ADV|top"))
				factor = 329.65376247015524;
			else if(feature.equals("posNgram_NN_SATZENDE_ART|top"))
				factor = 231.74534369503965;
			else if(feature.equals("posNgram_NN_SATZENDE_NE|top"))
				factor = 276.7416427368155;
			else if(feature.equals("posNgram_NN_SATZENDE_NN|top"))
				factor = 186.76897650152668;
			else if(feature.equals("posNgram_NN_SATZINTERN_NE|top"))
				factor = 144.953543993135;
			else if(feature.equals("posNgram_NN_SATZINTERN_NN|top"))
				factor = 38.31489315899629;
			else if(feature.equals("posNgram_NN_VVFIN_APPR|top"))
				factor = 376.1353229269319;
			else if(feature.equals("posNgram_NN_VVFIN_ART|top"))
				factor = 276.97757830994857;
			else if(feature.equals("posNgram_NN_VVFIN_KOMMA|top"))
				factor = 341.33348348965575;
			else if(feature.equals("posNgram_NN_VVFIN_PPER|top"))
				factor = 323.3720976946244;
			else if(feature.equals("posNgram_NN_VVFIN_SATZENDE|top"))
				factor = 197.5831325836236;
			else if(feature.equals("posNgram_NN_VVINF_SATZENDE|top"))
				factor = 199.5512342080281;
			else if(feature.equals("posNgram_NN_VVPP_SATZENDE|top"))
				factor = 180.40140601291768;
			else if(feature.equals("posNgram_NN_VVPP_VAFIN|top"))
				factor = 318.0558150360311;
			else if(feature.equals("posNgram_PTKZU_VVINF_SATZENDE|top"))
				factor = 284.3226837932323;
			else if(feature.equals("posNgram_SATZENDE_ADJA_NN|top"))
				factor = 219.21522076076462;
			else if(feature.equals("posNgram_SATZENDE_ADV_VVFIN|top"))
				factor = 340.30784044338645;
			else if(feature.equals("posNgram_SATZENDE_ART_ADJA|top"))
				factor = 292.9862069277395;
			else if(feature.equals("posNgram_SATZENDE_ART_NN|top"))
				factor = 112.5430070235555;
			else if(feature.equals("posNgram_SATZENDE_CARD_NN|top"))
				factor = 962.4454784458482;
			else if(feature.equals("posNgram_SATZENDE_PPER_VVFIN|top"))
				factor = 470.1310823679885;
			else if(feature.equals("posNgram_SATZINTERN_ADJA_NN|top"))
				factor = 294.1307214185679;
			else if(feature.equals("posNgram_SATZINTERN_NE_SATZINTERN|top"))
				factor = 198.72999038279366;
			else if(feature.equals("posNgram_SATZINTERN_NN_APPR|top"))
				factor = 174.61441063150517;
			else if(feature.equals("posNgram_SATZINTERN_NN_KOMMA|top"))
				factor = 275.59619379566755;
			else if(feature.equals("posNgram_SATZINTERN_NN_NE|top"))
				factor = 376.1078682790632;
			else if(feature.equals("posNgram_SATZINTERN_NN_NN|top"))
				factor = 173.3042875330945;
			else if(feature.equals("posNgram_SATZINTERN_NN_SATZENDE|top"))
				factor = 198.25940324124227;
			else if(feature.equals("posNgram_SATZINTERN_NN_SATZINTERN|top"))
				factor = 134.10584256559798;
			else if(feature.equals("posNgram_SATZINTERN_NN_VVFIN|top"))
				factor = 245.8054750938623;
			else if(feature.equals("posNgram_VAFIN_ART_NN|top"))
				factor = 234.63556075517107;
			else if(feature.equals("posNgram_VVFIN_ART_ADJA|top"))
				factor = 416.5940044528694;
			else if(feature.equals("posNgram_VVFIN_ART_NN|top"))
				factor = 161.27900961558447;
			else if(feature.equals("posNgram_VVFIN_PPER_ADV|top"))
				factor = 330.87393572374106;
			else if(feature.equals("posNgram_VVPP_VAFIN_SATZENDE|top"))
				factor = 386.25370795811637;
			else 
				System.err.println("Fehler bei POSNgram "+feature);
		}
		return factor * value / numberOfTokens;

	}

}
