package de.upb.infexba.ml.feature.partofspeech;

/**
 * Lists of POS-tags.
 * see: http://www.coli.uni-saarland.de/projects/sfb378/negra-corpus/stts.asc
 * 
 * @author kabu
 * 
 */
public class PartOfSpeechConstants {

	/**
	 * a POS tag
	 */
	public static final String ADJA = "ADJA", ADJD = "ADJD", ADV = "ADV", APPR = "APPR", APPRART = "APPRART", APPO = "APPO", APZR = "APZR",
			ART = "ART", CARD = "CARD", FM = "FM", ITJ = "ITJ", KOUI = "KOUI", KOUS = "KOUS", KON = "KON", KOKOM = "KOKOM", NN = "NN",
			NE = "NE", PDS = "PDS", PDAT = "PDAT", PIS = "PIS", PIAT = "PIAT", PIDAT = "PIDAT", PPER = "PPER", PPOSS = "PPOSS",
			PPOSAT = "PPOSAT", PRELS = "PRELS", PRELAT = "PRELAT", PRF = "PRF", PWS = "PWS", PWAV = "PWAV", PAV = "PAV", PTKZU = "PTKZU",
			PTKNEG = "PTKNEG", PTKVZ = "PTKVZ", PTKANT = "PTKANT", PTKA = "PTKA", TRUNC = "TRUNC", VVFIN = "VVFIN", VVIMP = "VVIMP",
			VVINF = "VVINF", VVIZU = "VVIZU", VVPP = "VVPP", VAFIN = "VAFIN", VAIMP = "VAIMP", VAINF = "VAINF", VAPP = "VAPP",
			VMFIN = "VMFIN", VMINF = "VMINF", VMPP = "VMPP", XY = "XY", KOMMA = "$,", SATZENDE = "$.", SATZINTERN = "$(";

	private static final String KOMMA_TXT = "KOMMA",  SATZENDE_TXT = "SATZENDE", SATZINTERN_TXT = "SATZINTERN";
	
	/**
	 * is empty.
	 */
	public static final String[] NONE = {};

	/**
	 * contains all POS tags.
	 */
	public static final String[] ALL = { /* 1 */"ADJA", "ADJD", "ADV", "APPR", "APPRART", "APPO", "APZR", "ART", "CARD", "FM", "ITJ",
			"KOUI", "KOUS", "KON", "KOKOM", "NN", "NE", /* 2 */
			"PDS", "PDAT", "PIS", "PIAT", "PIDAT", "PPER", "PPOSS", "PPOSAT", "PRELS", "PRELAT", "PRF", "PWS", "PWAV", "PAV", "PTKZU",
			"PTKNEG", "PTKVZ", "PTKANT", "PTKA", "TRUNC", /* 3 */"VVFIN", "VVIMP", "VVINF", "VVIZU", "VVPP", "VAFIN", "VAIMP", "VAINF",
			"VAPP", "VMFIN", "VMINF", "VMPP",/* 4 */XY, KOMMA, SATZENDE, SATZINTERN };

	public static final String[] VERB = { /* 3 */"VVFIN", "VVIMP", "VVINF", "VVIZU", "VVPP", "VAFIN", "VAIMP", "VAINF", "VAPP", "VMFIN",
			"VMINF", "VMPP" };

	public static final String[] ADJKONJ = { "ADJA", "ADJD", "ADV", "APPR", "APPRART", "APPO", "APZR", "ART", "ITJ", "KOUI", "KOUS", "KON",
			"KOKOM" };

	public static final String[] PRON_NN = { "PDS", "PDAT", "PIS", "PIAT", "PIDAT", "PPER", "PPOSS", "PPOSAT", "PRELS", "PRELAT", "PRF",
			"PWS", "PWAV", "PAV", "PTKZU", "PTKNEG", "PTKVZ", "PTKANT", "PTKA", "NN" };

	public static final String[] PERS_PROSSESSIV = { "PDS", "PDAT", "PIS", "PIAT", "PIDAT", "PPER", "PPOSS", "PPOSAT", "PRELS", "PRELAT",
			"PRF", "PWS", "PWAV", "PAV" };

	public static final String[] NOUN_ADJ = { "ADJA", "ADJD", "ADV", "APPR", "APPRART", "APPO", "APZR", "ART", "NN" }; 
	
	public static final String[] NOVERB = { "PDS", "PDAT", "PIS", "PIAT", "PIDAT", "PPER", "PPOSS", "PPOSAT", "PRELS", "PRELAT", "PRF",
			"PWS", "PWAV", "PAV", "PTKZU", "PTKNEG", "PTKVZ", "PTKANT", "PTKA", "NN", "ADJA", "ADJD", "ADV", "APPR", "APPRART", "APPO",
			"APZR", "ART", "ITJ", "KOUI", "KOUS", "KON", "KOKOM" };

	public static final String[] NOPRONNN = { /* 3 */"VVFIN", "VVIMP", "VVINF", "VVIZU", "VVPP", "VAFIN", "VAIMP", "VAINF", "VAPP", "VMFIN",
			"VMINF", "VMPP", "ADJA", "ADJD", "ADV", "APPR", "APPRART", "APPO", "APZR", "ART", "ITJ", "KOUI", "KOUS", "KON", "KOKOM" };

	public static final String[] NOADJKONJ = { /* 3 */"VVFIN", "VVIMP", "VVINF", "VVIZU", "VVPP", "VAFIN", "VAIMP", "VAINF", "VAPP",
			"VMFIN", "VMINF", "VMPP", "PDS", "PDAT", "PIS", "PIAT", "PIDAT", "PPER", "PPOSS", "PPOSAT", "PRELS", "PRELAT", "PRF", "PWS",
			"PWAV", "PAV", "PTKZU", "PTKNEG", "PTKVZ", "PTKANT", "PTKA", "NN" };

		
	/**
	 * returns true if an only if the given POS tag indicates that the corresponding word is not a word, i.e. a special
	 * character or non-word that contains special characters.
	 * 
	 * @param posTag
	 * @return
	 */
	public static boolean isNoWord(String posTag) {
		return posTag.equalsIgnoreCase(PartOfSpeechConstants.XY) || posTag.equalsIgnoreCase(PartOfSpeechConstants.SATZENDE)
				|| posTag.equalsIgnoreCase(PartOfSpeechConstants.SATZINTERN) || posTag.equalsIgnoreCase(PartOfSpeechConstants.KOMMA);
	}
	
	/**
	 * returns a string representation without special signs for the given POS-tag.
	 *  
	 * @param pos
	 * @return
	 */
	public static String getPosAsText(String pos){
		if(pos.equals(SATZENDE))
			return SATZENDE_TXT;
		if(pos.equals(KOMMA))
			return KOMMA_TXT;
		if(pos.equals(SATZINTERN))
			return SATZINTERN_TXT;
		return pos;
	}
	
	public static String getPosFromText(String pos_txt){
		if(pos_txt.equals(SATZENDE_TXT))
			return SATZENDE;
		if(pos_txt.equals(KOMMA_TXT))
			return KOMMA;
		if(pos_txt.equals(SATZINTERN_TXT))
			return SATZINTERN;
		return pos_txt;		
	}
}
